@@ -357,30 +357,3 @@ class HpsVoid(HpsTransaction):
         void.response_text = ''
 
         return void
-
-
-class HpsCPCEdit(HpsTransaction):
-    @classmethod
-    def from_dict(cls, rsp):
-        edit = super(HpsCPCEdit, cls).from_dict(rsp)
-        edit.response_code = '00'
-        edit.response_text = ''
-
-        return edit
-
-
-class HpsCPCData:
-    card_holder_po_number = None
-    tax_type = None
-    tax_amount = None
-
-    def __init__(self, card_holder_po_number=None, tax_type=None, tax_amount=None):
-        if card_holder_po_number is not None:
-            if len(card_holder_po_number) > 17:
-                raise HpsArgumentException('Card holder po number must be less that 17 characters.')
-            self.card_holder_po_number = card_holder_po_number
-
-        self.tax_type = tax_type
-
-        if tax_amount is not None:
-            self.tax_amount = tax_amount
