@@ -15,11 +15,6 @@ class HpsException(Exception):
         self.inner_exception = inner_exception
 
 
-class HpsArgumentException(HpsException):
-    def __init__(self, message, inner_exception=None):
-        HpsException.__init__(self, message, inner_exception)
-
-
 class HpsAuthenticationException(HpsException):
     code = None
 
@@ -28,7 +23,7 @@ class HpsAuthenticationException(HpsException):
         self.message = message
 
 
-class HpsCheckException(HpsException):
+class HpsCheckException(Exception):
     transaction_id = None
     code = None
     details = None
@@ -40,7 +35,7 @@ class HpsCheckException(HpsException):
         self.message = message
 
 
-class HpsConfiguration:
+class HpsConfiguration(object):
     secret_api_key = None
     license_id = -1
     site_id = -1
@@ -72,7 +67,7 @@ class HpsConfiguration:
                 self.version_number = parser.get('Settings', 'versionNbr')
                 self.soap_service_uri = parser.get('Settings', 'URL')
             except NoOptionError:
-                raise HpsException('Could not read config file.')
+                raise Exception('Could not read config file.')
 
 
 class HpsCreditException(HpsException):
@@ -93,13 +88,10 @@ class HpsCreditException(HpsException):
             HpsException.__init__(self, message, inner_exception)
 
 
-class HpsCreditExceptionDetails:
+class HpsCreditExceptionDetails(object):
     issuer_response_code = None
     issuer_response_text = None
 
-    def __init__(self):
-        pass
-
 
 class HpsGatewayException(HpsException):
     code = None
@@ -122,13 +114,10 @@ class HpsGatewayException(HpsException):
             self.inner_exception = inner_exception
 
 
-class HpsGatewayExceptionDetails:
+class HpsGatewayExceptionDetails(object):
     gateway_response_code = None
     gateway_response_message = None
 
-    def __init__(self):
-        pass
-
 
 class HpsInvalidRequestException(HpsException):
     code = None
