@@ -23,33 +23,21 @@ class HpsError(object):
         return error
 
 
-class HpsToken:
+class HpsToken(object):
     object = None
     token_type = None
     token_value = None
     token_expire = None
+    card = None
     error = None
 
-    def __init__(self):
-        self.object = 'token'
-        self.token_type = 'supt'
-
-    @classmethod
-    def from_dict(cls, data):
-        token = cls()
-        for key in data:
-            if key == 'error':
-                token.error = HpsError.from_dict(data[key])
-            else:
-                setattr(token, key, data[key])
-        return token
-
-
-class HpsCardToken(HpsToken):
-    card = None
-
-    def __init__(self, card_data=None, cvc=None, exp_month=None, exp_year=None):
-        HpsToken.__init__(self)
+    def __init__(self,
+                 card_data=None,
+                 cvc=None,
+                 exp_month=None,
+                 exp_year=None):
+        self.object = "token"
+        self.token_type = "supt"
 
         if card_data is not None:
             if isinstance(card_data, HpsCreditCard):
@@ -60,18 +48,17 @@ class HpsCardToken(HpsToken):
             else:
                 self.card = Card(card_data, cvc, exp_month, exp_year)
 
-
-class HpsEncryptedCardToken(HpsToken):
-    encryptedcard = None
-
-    def __init__(self, track_data=None, track_number=None, ktb=None, pin_block=None):
-        HpsToken.__init__(self)
-
-        if track_data is not None:
-            if isinstance(track_data, EncryptedCard):
-                self.encryptedcard = EncryptedCard()
+    @classmethod
+    def from_dict(cls, data):
+        token = cls()
+        for key in data:
+            if key == "card":
+                token.card = Card.from_dict(data[key])
+            elif key == "error":
+                token.error = HpsError.from_dict(data[key])
             else:
-                self.encryptedcard = EncryptedCard(track_data, track_number, ktb, pin_block)
+                setattr(token, key, data[key])
+        return token
 
 
 class Card(object):
@@ -86,17 +73,9 @@ class Card(object):
         self.exp_month = exp_month
         self.exp_year = exp_year
 
-
-class EncryptedCard:
-    track = None
-    track_method = None
-    track_number = None
-    pin_block = None
-    ktb = None
-
-    def __init__(self, track=None, track_number=None, ktb=None, pin_block=None):
-        self.track = track
-        self.track_number = track_number
-        self.ktb = ktb
-        self.pin_block = pin_block
-        self.track_method = 'swipe'
+    @classmethod
+    def from_dict(cls, data):
+        card = cls(None, None, None, None)
+        for key in data:
+            setattr(card, key, data[key])
+        return card
