@@ -7,15 +7,9 @@
 """
 
 import urllib2
-import datetime
-import xml.etree.cElementTree as et
+import xml.etree.cElementTree as Et
 import xmltodict as xmltodict
-from xml.dom import minidom
-from enum import Enum
-from securesubmit.services.core import HpsServicesConfig
-from securesubmit.infrastructure.core import *
-from securesubmit.infrastructure.validation import *
-from securesubmit.entities import *
+from securesubmit.infrastructure import *
 from securesubmit.entities.credit import *
 from securesubmit.entities.batch import *
 from securesubmit.entities.check import *
@@ -62,7 +56,7 @@ class HpsGatewayService(object):
         self._config = value
 
     def do_transaction(self, transaction, client_transaction_id=None):
-        if(self._is_config_invalid()):
+        if self._is_config_invalid():
             raise HpsAuthenticationException(
                 HpsExceptionCodes.invalid_configuration,
                 ('The HPS SDK has not been properly configured. '
@@ -71,22 +65,22 @@ class HpsGatewayService(object):
                  'or Web.config file.'))
         try:
             # Envelope
-            envelope = et.Element("soap:Envelope")
+            envelope = Et.Element("soap:Envelope")
             envelope.set("xmlns:soap",
                          "http://schemas.xmlsoap.org/soap/envelope/")
             envelope.set("xmlns:xsi",
                          "http://www.w3.org/2001/XMLSchema-instance")
             envelope.set("xmlns:xsd",
                          "http://www.w3.org/2001/XMLSchema")
-            body = et.SubElement(envelope, "soap:Body")
+            body = Et.SubElement(envelope, "soap:Body")
 
             # Request
-            request = et.SubElement(body, "PosRequest")
+            request = Et.SubElement(body, "PosRequest")
             request.set("xmlns", "http://Hps.Exchange.PosGateway")
-            version1 = et.SubElement(request, "Ver1.0")
+            version1 = Et.SubElement(request, "Ver1.0")
 
             # Header
-            header = et.SubElement(version1, "Header")
+            header = Et.SubElement(version1, "Header")
             secret_api_key = None
             if self._config is not None:
                 secret_api_key = self._config.secret_api_key
@@ -94,14 +88,14 @@ class HpsGatewayService(object):
                 secret_api_key = self._base_config.secret_api_key
 
             if secret_api_key is not None and secret_api_key != "":
-                api_key = et.SubElement(header, "SecretAPIKey")
+                api_key = Et.SubElement(header, "SecretAPIKey")
                 api_key.text = secret_api_key
             else:
-                site_id = et.SubElement(header, 'SiteId')
-                device_id = et.SubElement(header, 'DeviceId')
-                license_id = et.SubElement(header, 'LicenseId')
-                username = et.SubElement(header, 'UserName')
-                password = et.SubElement(header, 'Password')
+                site_id = Et.SubElement(header, 'SiteId')
+                device_id = Et.SubElement(header, 'DeviceId')
+                license_id = Et.SubElement(header, 'LicenseId')
+                username = Et.SubElement(header, 'UserName')
+                password = Et.SubElement(header, 'Password')
 
                 if self._config is not None:
                     site_id.text = str(self._config.site_id)
@@ -123,19 +117,19 @@ class HpsGatewayService(object):
                 version_id = self._config.version_number
 
             if developer_id != '' and developer_id is not None:
-                et.SubElement(header, 'DeveloperID').text = developer_id
+                Et.SubElement(header, 'DeveloperID').text = developer_id
             if version_id != '' and version_id is not None:
-                et.SubElement(header, 'VersionNbr').text = version_id
+                Et.SubElement(header, 'VersionNbr').text = version_id
 
             if client_transaction_id is not None:
-                client_txn_id = et.SubElement(header, 'ClientTxnId')
+                client_txn_id = Et.SubElement(header, 'ClientTxnId')
                 client_txn_id.text = client_transaction_id
 
             # Transaction
-            trans = et.SubElement(version1, "Transaction")
+            trans = Et.SubElement(version1, "Transaction")
             trans.append(transaction)
 
-            xml = et.tostring(envelope).encode('utf-8')
+            xml = Et.tostring(envelope).encode('utf-8')
             request_headers = {'Content-type': 'text/xml; charset=UTF-8',
                                'Content-length': len(xml),
                                'Host': 'posgateway.cert.secureexchange.net'}
@@ -154,7 +148,7 @@ class HpsGatewayService(object):
                     'PosResponse' in response['Envelope']['Body']):
                 return response['Envelope']['Body']['PosResponse']
             else:
-                raise ApiConnectionException("Unexpected response")
+                raise HpsException("Unexpected response")
         except Exception, e:
             raise HpsGatewayException(
                 HpsExceptionCodes.unknown_gateway_error,
@@ -175,15 +169,6 @@ class HpsGatewayService(object):
         else:
             return False
 
-        """
-    HpsCreditService.py
-    ~~~~~~~~~~~~~~~~~~~
-
-    The HPS charge service.
-
-    :copyright: (c) Heartland Payment Systems. All rights reserved.
-"""
-
 
 class HpsCreditService(HpsGatewayService):
     _filter_by = None
@@ -196,8 +181,8 @@ class HpsCreditService(HpsGatewayService):
             raise ValueError('Invalid transaction id.')
 
         # Build the transaction request.
-        transaction = et.Element("ReportTxnDetail")
-        et.SubElement(transaction, "TxnId").text = str(transaction_id)
+        transaction = Et.Element("ReportTxnDetail")
+        Et.SubElement(transaction, "TxnId").text = str(transaction_id)
 
         return self._submit_transaction(transaction)
 
@@ -205,14 +190,14 @@ class HpsCreditService(HpsGatewayService):
         HpsInputValidation.check_date_not_future(utc_start)
         HpsInputValidation.check_date_not_future(utc_end)
 
-        transaction = et.Element("ReportActivity")
+        transaction = Et.Element("ReportActivity")
 
         if utc_start is not None:
-            start = et.SubElement(transaction, "RptStartUtcDT")
+            start = Et.SubElement(transaction, "RptStartUtcDT")
             start.text = utc_start.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
 
         if utc_end is not None:
-            end = et.SubElement(transaction, "RptEndUtcDT")
+            end = Et.SubElement(transaction, "RptEndUtcDT")
             end.text = utc_end.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
 
         return self._submit_transaction(transaction)
@@ -227,31 +212,32 @@ class HpsCreditService(HpsGatewayService):
         HpsInputValidation.check_currency(currency)
 
         # Built the transaction request
-        transaction = et.Element('CreditSale')
-        block1 = et.SubElement(transaction, 'Block1')
-        et.SubElement(block1, 'AllowDup').text = 'Y'
-        partial_auth = et.SubElement(block1, 'AllowPartialAuth')
+        transaction = Et.Element('CreditSale')
+        block1 = Et.SubElement(transaction, 'Block1')
+        Et.SubElement(block1, 'AllowDup').text = 'Y'
+        partial_auth = Et.SubElement(block1, 'AllowPartialAuth')
         if allow_partial_auth:
             partial_auth.text = 'Y'
         else:
             partial_auth.text = 'N'
 
-        et.SubElement(block1, 'Amt').text = str(amount)
+        Et.SubElement(block1, 'Amt').text = str(amount)
 
         # Add Card Holder
         if card_holder is not None:
             block1.append(self._hydrate_card_holder_data(card_holder))
 
         # Add Card Data
-        card_data_element = et.SubElement(block1, 'CardData')
+        card_data_element = Et.SubElement(block1, 'CardData')
         if isinstance(card_data, HpsCreditCard):
-            card_data_element.append(self._hydate_card_manual_entry(card_data))
+            card_data_element.append(
+                self._hydrate_card_manual_entry(card_data))
         else:
-            token_data = et.SubElement(card_data_element, 'TokenData')
-            et.SubElement(token_data, 'TokenValue').text = card_data
+            token_data = Et.SubElement(card_data_element, 'TokenData')
+            Et.SubElement(token_data, 'TokenValue').text = card_data
 
         # Add Token Request
-        token_request = et.SubElement(card_data_element, 'TokenRequest')
+        token_request = Et.SubElement(card_data_element, 'TokenRequest')
         if request_multi_use_token:
             token_request.text = 'Y'
         else:
@@ -262,7 +248,7 @@ class HpsCreditService(HpsGatewayService):
             block1.append(self._hydrate_additional_txn_fields(details))
 
         if descriptor is not None:
-            et.SubElement(block1, "TxnDescriptor").text = descriptor
+            Et.SubElement(block1, "TxnDescriptor").text = descriptor
 
         # Submit the transaction
         client_txn_id = self._get_client_txn_id(details)
@@ -273,23 +259,24 @@ class HpsCreditService(HpsGatewayService):
                request_multi_use_token=False,
                client_transaction_id=None):
         # Build the transaction request.
-        transaction = et.Element('CreditAccountVerify')
-        block1 = et.SubElement(transaction, 'Block1')
+        transaction = Et.Element('CreditAccountVerify')
+        block1 = Et.SubElement(transaction, 'Block1')
 
         # Add Card Holder
         if card_holder is not None:
             block1.append(self._hydrate_card_holder_data(card_holder))
 
         # Add Card Data
-        card_data_element = et.SubElement(block1, 'CardData')
+        card_data_element = Et.SubElement(block1, 'CardData')
         if isinstance(card_data, HpsCreditCard):
-            card_data_element.append(self._hydate_card_manual_entry(card_data))
+            card_data_element.append(
+                self._hydrate_card_manual_entry(card_data))
         else:
-            token_data = et.SubElement(card_data_element, 'TokenData')
-            et.SubElement(token_data, 'TokenValue').text = card_data
+            token_data = Et.SubElement(card_data_element, 'TokenData')
+            Et.SubElement(token_data, 'TokenValue').text = card_data
 
         # Add Token Request
-        token_request = et.SubElement(card_data_element, 'TokenRequest')
+        token_request = Et.SubElement(card_data_element, 'TokenRequest')
         if request_multi_use_token:
             token_request.text = 'Y'
         else:
@@ -307,31 +294,32 @@ class HpsCreditService(HpsGatewayService):
         HpsInputValidation.check_currency(currency)
 
         # Build the transaction Request
-        transaction = et.Element('CreditAuth')
-        block1 = et.SubElement(transaction, 'Block1')
-        et.SubElement(block1, 'AllowDup').text = 'Y'
-        partial_auth = et.SubElement(block1, 'AllowPartialAuth')
+        transaction = Et.Element('CreditAuth')
+        block1 = Et.SubElement(transaction, 'Block1')
+        Et.SubElement(block1, 'AllowDup').text = 'Y'
+        partial_auth = Et.SubElement(block1, 'AllowPartialAuth')
         if allow_partial_auth:
             partial_auth.text = 'Y'
         else:
             partial_auth.text = 'N'
 
-        et.SubElement(block1, 'Amt').text = str(amount)
+        Et.SubElement(block1, 'Amt').text = str(amount)
 
         # Add Card Holder
         if card_holder is not None:
             block1.append(self._hydrate_card_holder_data(card_holder))
 
         # Add Card Data
-        card_data_element = et.SubElement(block1, 'CardData')
+        card_data_element = Et.SubElement(block1, 'CardData')
         if isinstance(card_data, HpsCreditCard):
-            card_data_element.append(self._hydate_card_manual_entry(card_data))
+            card_data_element.append(
+                self._hydrate_card_manual_entry(card_data))
         else:
-            token_data = et.SubElement(card_data_element, 'TokenData')
-            et.SubElement(token_data, 'TokenValue').text = card_data
+            token_data = Et.SubElement(card_data_element, 'TokenData')
+            Et.SubElement(token_data, 'TokenValue').text = card_data
 
         # Add Token Request
-        token_request = et.SubElement(card_data_element, 'TokenRequest')
+        token_request = Et.SubElement(card_data_element, 'TokenRequest')
         if request_multi_use_token:
             token_request.text = 'Y'
         else:
@@ -342,7 +330,7 @@ class HpsCreditService(HpsGatewayService):
             block1.append(self._hydrate_additional_txn_fields(details))
 
         if descriptor is not None:
-            et.SubElement(block1, "TxnDescriptor").text = descriptor
+            Et.SubElement(block1, "TxnDescriptor").text = descriptor
 
         client_txn_id = self._get_client_txn_id(details)
         return self._submit_transaction(transaction, client_txn_id)
@@ -352,14 +340,14 @@ class HpsCreditService(HpsGatewayService):
                 gratuity=None,
                 client_transaction_id=None):
         # Build the transaction request.
-        transaction = et.Element('CreditAddToBatch')
-        et.SubElement(transaction, 'GatewayTxnId').text = str(transaction_id)
+        transaction = Et.Element('CreditAddToBatch')
+        Et.SubElement(transaction, 'GatewayTxnId').text = str(transaction_id)
         if amount is not None:
-            et.SubElement(transaction, 'Amt').text = str(amount)
+            Et.SubElement(transaction, 'Amt').text = str(amount)
 
         # Add Gratuity
         if gratuity is not None:
-            et.SubElement(transaction, 'GratuityAmtInfo').text = str(gratuity)
+            Et.SubElement(transaction, 'GratuityAmtInfo').text = str(gratuity)
 
         # Submit the transaction
         rsp = self.do_transaction(transaction, client_transaction_id)["Ver1.0"]
@@ -374,10 +362,10 @@ class HpsCreditService(HpsGatewayService):
         HpsInputValidation.check_currency(currency)
 
         # Build the transaction request
-        transaction = et.Element('CreditReturn')
-        block1 = et.SubElement(transaction, 'Block1')
-        et.SubElement(block1, 'AllowDup').text = "Y"
-        et.SubElement(block1, 'Amt').text = str(amount)
+        transaction = Et.Element('CreditReturn')
+        block1 = Et.SubElement(transaction, 'Block1')
+        Et.SubElement(block1, 'AllowDup').text = "Y"
+        Et.SubElement(block1, 'Amt').text = str(amount)
 
         # Add Card Holder
         if card_holder is not None:
@@ -385,14 +373,15 @@ class HpsCreditService(HpsGatewayService):
 
         # Card Data
         if isinstance(card_data, HpsCreditCard):
-            card_data_element = et.SubElement(block1, 'CardData')
-            card_data_element.append(self._hydate_card_manual_entry(card_data))
+            card_data_element = Et.SubElement(block1, 'CardData')
+            card_data_element.append(
+                self._hydrate_card_manual_entry(card_data))
         elif isinstance(card_data, (basestring, str)):
-            card_data_element = et.SubElement(block1, 'CardData')
-            token_data = et.SubElement(card_data_element, 'TokenData')
-            et.SubElement(token_data, 'TokenValue').text = card_data
+            card_data_element = Et.SubElement(block1, 'CardData')
+            token_data = Et.SubElement(card_data_element, 'TokenData')
+            Et.SubElement(token_data, 'TokenValue').text = card_data
         else:
-            et.SubElement(block1, 'GatewayTxnId').text = str(card_data)
+            Et.SubElement(block1, 'GatewayTxnId').text = str(card_data)
 
         # Additional Txn
         if details is not None:
@@ -406,20 +395,21 @@ class HpsCreditService(HpsGatewayService):
         HpsInputValidation.check_currency(currency)
 
         # Build the transaction request
-        transaction = et.Element('CreditReversal')
-        block1 = et.SubElement(transaction, 'Block1')
-        et.SubElement(block1, 'Amt').text = str(amount)
+        transaction = Et.Element('CreditReversal')
+        block1 = Et.SubElement(transaction, 'Block1')
+        Et.SubElement(block1, 'Amt').text = str(amount)
 
         # Card Data
         if isinstance(card_data, HpsCreditCard):
-            card_data_element = et.SubElement(block1, 'CardData')
-            card_data_element.append(self._hydate_card_manual_entry(card_data))
+            card_data_element = Et.SubElement(block1, 'CardData')
+            card_data_element.append(
+                self._hydrate_card_manual_entry(card_data))
         elif isinstance(card_data, (basestring, str)):
-            card_data_element = et.SubElement(block1, 'CardData')
-            token_data = et.SubElement(card_data_element, 'TokenData')
-            et.SubElement(token_data, 'TokenValue').text = card_data
+            card_data_element = Et.SubElement(block1, 'CardData')
+            token_data = Et.SubElement(card_data_element, 'TokenData')
+            Et.SubElement(token_data, 'TokenValue').text = card_data
         else:
-            et.SubElement(block1, 'GatewayTxnId').text = str(card_data)
+            Et.SubElement(block1, 'GatewayTxnId').text = str(card_data)
 
         # Additional Txn
         if details is not None:
@@ -429,8 +419,8 @@ class HpsCreditService(HpsGatewayService):
         return self._submit_transaction(transaction, client_txn_id)
 
     def void(self, transaction_id, client_transaction_id=None):
-        transaction = et.Element('CreditVoid')
-        et.SubElement(transaction, 'GatewayTxnId').text = str(transaction_id)
+        transaction = Et.Element('CreditVoid')
+        Et.SubElement(transaction, 'GatewayTxnId').text = str(transaction_id)
 
         return self._submit_transaction(transaction, client_transaction_id)
 
@@ -439,15 +429,15 @@ class HpsCreditService(HpsGatewayService):
              amount=None,
              gratuity=None,
              client_transaction_id=None):
-        transaction = et.Element('CreditTxnEdit')
-        et.SubElement(transaction, 'GatewayTxnId').text = str(transaction_id)
+        transaction = Et.Element('CreditTxnEdit')
+        Et.SubElement(transaction, 'GatewayTxnId').text = str(transaction_id)
 
         if amount is not None:
-            et.SubElement(transaction, 'Amt').text = str(amount)
+            Et.SubElement(transaction, 'Amt').text = str(amount)
 
         # Add Gratuity
         if gratuity is not None:
-            et.SubElement(transaction, 'GratuityAmtInfo').text = str(gratuity)
+            Et.SubElement(transaction, 'GratuityAmtInfo').text = str(gratuity)
 
         # Submit the transaction
         trans = self._submit_transaction(transaction, client_transaction_id)
@@ -470,6 +460,7 @@ class HpsCreditService(HpsGatewayService):
         self._process_charge_issuer_response(
             rsp, transaction.tag, amount, 'usd')
 
+        rvalue = None
         if transaction.tag == 'ReportTxnDetail':
             rvalue = HpsReportTransactionDetails.from_dict(rsp)
         elif transaction.tag == 'ReportActivity':
@@ -494,40 +485,40 @@ class HpsCreditService(HpsGatewayService):
 
     def _hydrate_card_holder_data(self, card_holder):
         """Hydrate a new HPS card holder data type."""
-        holder = et.Element('CardHolderData')
-        et.SubElement(holder,
+        holder = Et.Element('CardHolderData')
+        Et.SubElement(holder,
                       'CardHolderFirstName').text = card_holder.first_name
-        et.SubElement(holder,
+        Et.SubElement(holder,
                       'CardHolderLastName').text = card_holder.last_name
-        if holder.email is not None:
-            et.SubElement(holder,
+        if card_holder.email is not None:
+            Et.SubElement(holder,
                           'CardHolderEmail').text = card_holder.email
-        if holder.phone is not None:
-                et.SubElement(holder,
+        if card_holder.phone is not None:
+                Et.SubElement(holder,
                               'CardHolderPhone').text = card_holder.phone
-        et.SubElement(holder,
+        Et.SubElement(holder,
                       'CardHolderAddr').text = card_holder.address.address
-        et.SubElement(holder,
+        Et.SubElement(holder,
                       'CardHolderCity').text = card_holder.address.city
-        et.SubElement(holder,
+        Et.SubElement(holder,
                       'CardHolderState').text = card_holder.address.state
-        et.SubElement(holder,
+        Et.SubElement(holder,
                       'CardHolderZip').text = card_holder.address.zip
 
         return holder
 
-    def _hydate_card_manual_entry(self, card):
+    def _hydrate_card_manual_entry(self, card):
         """Hydrate a new HPS manual entry card data type."""
 
-        manual_entry = et.Element('ManualEntry')
-        et.SubElement(manual_entry, 'CardNbr').text = card.number
-        et.SubElement(manual_entry, 'ExpMonth').text = str(card.exp_month)
-        et.SubElement(manual_entry, 'ExpYear').text = str(card.exp_year)
+        manual_entry = Et.Element('ManualEntry')
+        Et.SubElement(manual_entry, 'CardNbr').text = card.number
+        Et.SubElement(manual_entry, 'ExpMonth').text = str(card.exp_month)
+        Et.SubElement(manual_entry, 'ExpYear').text = str(card.exp_year)
         if card.cvv is not None:
-            cvv_element = et.SubElement(manual_entry, 'CVV2')
+            cvv_element = Et.SubElement(manual_entry, 'CVV2')
             cvv_element.text = str(card.cvv)
-        et.SubElement(manual_entry, 'CardPresent').text = "N"
-        et.SubElement(manual_entry, 'ReaderPresent').text = "N"
+        Et.SubElement(manual_entry, 'CardPresent').text = "N"
+        Et.SubElement(manual_entry, 'ReaderPresent').text = "N"
 
         return manual_entry
 
@@ -535,18 +526,18 @@ class HpsCreditService(HpsGatewayService):
         """Hydrate additional transaction fields."""
 
         if details is not None and isinstance(details, HpsTransactionDetails):
-            addons = et.Element('AdditionalTxnFields')
+            addons = Et.Element('AdditionalTxnFields')
 
             if details.memo is not None:
-                memo = et.SubElement(addons, 'Description')
+                memo = Et.SubElement(addons, 'Description')
                 memo.text = details.memo
 
             if details.customer_id is not None:
-                customer_id = et.SubElement(addons, "CustomerID")
+                customer_id = Et.SubElement(addons, "CustomerID")
                 customer_id.text = details.customer_id
 
             if details.invoice_number is not None:
-                invoice_number = et.SubElement(addons, "InvoiceNbr")
+                invoice_number = Et.SubElement(addons, "InvoiceNbr")
                 invoice_number.text = details.invoice_number
 
             return addons
@@ -621,7 +612,7 @@ class HpsBatchService(HpsGatewayService):
         HpsGatewayService.__init__(self, config)
 
     def close_batch(self):
-        transaction = et.Element('BatchClose')
+        transaction = Et.Element('BatchClose')
         rsp = self.do_transaction(transaction)["Ver1.0"]
         HpsGatewayResponseValidation.check_response(rsp, transaction.tag)
 
@@ -660,81 +651,81 @@ class HpsCheckService(HpsGatewayService):
                 HpsExceptionCodes.missing_check_name,
                 'For sec code CCD the check name is required.', 'check_name')
 
-        transaction = et.Element('CheckSale')
-        block1 = et.SubElement(transaction, 'Block1')
-        et.SubElement(block1, 'Amt').text = str(amount)
+        transaction = Et.Element('CheckSale')
+        block1 = Et.SubElement(transaction, 'Block1')
+        Et.SubElement(block1, 'Amt').text = str(amount)
 
-        account_info = et.SubElement(block1, 'AccountInfo')
+        account_info = Et.SubElement(block1, 'AccountInfo')
         if check.account_number is not None:
-            acc_number = et.SubElement(account_info, 'AccountNumber')
+            acc_number = Et.SubElement(account_info, 'AccountNumber')
             acc_number.text = check.account_number
         if check.check_number is not None:
-            check_number = et.SubElement(account_info, 'CheckNumber')
+            check_number = Et.SubElement(account_info, 'CheckNumber')
             check_number.text = check.check_number
         if check.micr_number is not None:
-            micr_data = et.SubElement(account_info, 'MICRData')
+            micr_data = Et.SubElement(account_info, 'MICRData')
             micr_data.text = check.micr_number
         if check.routing_number is not None:
-            routing_number = et.SubElement(account_info, 'RoutingNumber')
+            routing_number = Et.SubElement(account_info, 'RoutingNumber')
             routing_number.text = check.routing_number
 
         if check.account_type is not None:
-            acc_type = et.SubElement(account_info, 'AccountType')
+            acc_type = Et.SubElement(account_info, 'AccountType')
             acc_type.text = check.account_type
 
-        et.SubElement(block1, 'CheckAction').text = action
-        et.SubElement(block1, 'SECCode').text = check.sec_code
+        Et.SubElement(block1, 'CheckAction').text = action
+        Et.SubElement(block1, 'SECCode').text = check.sec_code
 
         if check.check_type is not None:
-            et.SubElement(block1, 'CheckType').text = check.check_type
+            Et.SubElement(block1, 'CheckType').text = check.check_type
         if check.data_entry_mode is not None:
-            et.SubElement(block1, 'DataEntryMode').text = check.data_entry_mode
+            Et.SubElement(block1, 'DataEntryMode').text = check.data_entry_mode
 
         if check.check_holder is not None:
-            consumer_info = et.SubElement(block1, 'ConsumerInfo')
+            consumer_info = Et.SubElement(block1, 'ConsumerInfo')
             if check.check_holder.address is not None:
-                addr1 = et.SubElement(consumer_info, 'Address1')
+                addr1 = Et.SubElement(consumer_info, 'Address1')
                 addr1.text = check.check_holder.address.address
 
-                city = et.SubElement(consumer_info, 'City')
+                city = Et.SubElement(consumer_info, 'City')
                 city.text = check.check_holder.address.city
 
-                state = et.SubElement(consumer_info, 'State')
+                state = Et.SubElement(consumer_info, 'State')
                 state.text = check.check_holder.address.state
 
-                zip = et.SubElement(consumer_info, 'Zip')
+                zip = Et.SubElement(consumer_info, 'Zip')
                 zip.text = check.check_holder.address.zip
 
             if check.check_holder.check_name is not None:
-                check_name = et.SubElement(consumer_info, 'CheckName')
+                check_name = Et.SubElement(consumer_info, 'CheckName')
                 check_name.text = check.check_holder.check_name
 
             if check.check_holder.courtesy_card is not None:
-                courtesy_card = et.SubElement(consumer_info, 'CourtesyCard')
+                courtesy_card = Et.SubElement(consumer_info, 'CourtesyCard')
                 courtesy_card.text = check.check_holder.courtesy_card
 
             if check.check_holder.dl_number is not None:
-                dl_number = et.SubElement(consumer_info, 'DLNumber')
+                dl_number = Et.SubElement(consumer_info, 'DLNumber')
                 dl_number.text = check.check_holder.dl_number
 
             if check.check_holder.dl_state is not None:
-                dl_state = et.SubElement(consumer_info, 'DLState')
+                dl_state = Et.SubElement(consumer_info, 'DLState')
                 dl_state.text = check.check_holder.dl_state
 
             if check.check_holder.email is not None:
-                email = et.SubElement(consumer_info, 'EmailAddress')
+                email = Et.SubElement(consumer_info, 'EmailAddress')
                 email.text = check.check_holder.email
 
             if check.check_holder.first_name is not None:
-                first_name = et.SubElement(consumer_info, 'FirstName')
+                first_name = Et.SubElement(consumer_info, 'FirstName')
                 first_name.text = check.check_holder.first_name
 
             if check.check_holder.last_name is not None:
-                last_name = et.SubElement(consumer_info, 'LastName')
+                last_name = Et.SubElement(consumer_info, 'LastName')
                 last_name.text = check.check_holder.last_name
 
             if check.check_holder.phone is not None:
-                phone_number = et.SubElement(consumer_info, 'PhoneNumber')
+                phone_number = Et.SubElement(consumer_info, 'PhoneNumber')
                 phone_number.text = check.check_holder.phone
 
         rsp = self.do_transaction(transaction)['Ver1.0']
@@ -748,13 +739,13 @@ class HpsCheckService(HpsGatewayService):
             raise HpsException(
                 'Please provide a transaction id or a client transaction id.')
 
-        transaction = et.Element('CheckVoid')
-        block1 = et.SubElement(transaction, 'Block1')
+        transaction = Et.Element('CheckVoid')
+        block1 = Et.SubElement(transaction, 'Block1')
 
         if transaction_id is not None:
-            et.SubElement(block1, 'GatewayTxnId').text = str(transaction_id)
+            Et.SubElement(block1, 'GatewayTxnId').text = str(transaction_id)
         else:
-            txn_id = et.SubElement(block1, 'ClientTxnId')
+            txn_id = Et.SubElement(block1, 'ClientTxnId')
             txn_id.text = str(client_transaction_id)
 
         return self._submit_transaction(transaction)
@@ -784,10 +775,10 @@ class HpsGiftCardService(HpsGatewayService):
         HpsInputValidation.check_amount(amount)
         HpsInputValidation.check_currency(currency)
 
-        transaction = et.Element('GiftCardActivate')
-        block1 = et.SubElement(transaction, 'Block1')
+        transaction = Et.Element('GiftCardActivate')
+        block1 = Et.SubElement(transaction, 'Block1')
 
-        et.SubElement(block1, 'Amt').text = str(amount)
+        Et.SubElement(block1, 'Amt').text = str(amount)
         block1.append(self._hydrate_gift_card_data(gift_card))
 
         return self._submit_transaction(transaction)
@@ -796,40 +787,40 @@ class HpsGiftCardService(HpsGatewayService):
         HpsInputValidation.check_amount(amount)
         HpsInputValidation.check_currency(currency)
 
-        transaction = et.Element('GiftCardAddValue')
-        block1 = et.SubElement(transaction, 'Block1')
+        transaction = Et.Element('GiftCardAddValue')
+        block1 = Et.SubElement(transaction, 'Block1')
 
-        et.SubElement(block1, 'Amt').text = str(amount)
+        Et.SubElement(block1, 'Amt').text = str(amount)
         block1.append(self._hydrate_gift_card_data(gift_card))
 
         return self._submit_transaction(transaction)
 
     def alias(self, action, gift_card, alias_str):
-        transaction = et.Element('GiftCardAlias')
-        block1 = et.SubElement(transaction, 'Block1')
-        et.SubElement(block1, 'Action').text = action
-        et.SubElement(block1, 'Alias').text = alias_str
+        transaction = Et.Element('GiftCardAlias')
+        block1 = Et.SubElement(transaction, 'Block1')
+        Et.SubElement(block1, 'Action').text = action
+        Et.SubElement(block1, 'Alias').text = alias_str
         block1.append(self._hydrate_gift_card_data(gift_card))
 
         return self._submit_transaction(transaction)
 
     def balance(self, gift_card):
-        transaction = et.Element('GiftCardBalance')
-        block1 = et.SubElement(transaction, 'Block1')
+        transaction = Et.Element('GiftCardBalance')
+        block1 = Et.SubElement(transaction, 'Block1')
         block1.append(self._hydrate_gift_card_data(gift_card))
 
         return self._submit_transaction(transaction)
 
     def deactivate(self, gift_card):
-        transaction = et.Element('GiftCardDeactivate')
-        block1 = et.SubElement(transaction, 'Block1')
+        transaction = Et.Element('GiftCardDeactivate')
+        block1 = Et.SubElement(transaction, 'Block1')
         block1.append(self._hydrate_gift_card_data(gift_card))
 
         return self._submit_transaction(transaction)
 
     def replace(self, old_gift_card, new_gift_card):
-        transaction = et.Element('GiftCardReplace')
-        block1 = et.SubElement(transaction, 'Block1')
+        transaction = Et.Element('GiftCardReplace')
+        block1 = Et.SubElement(transaction, 'Block1')
 
         block1.append(self._hydrate_gift_card_data(old_gift_card,
                                                    'OldCardData'))
@@ -843,23 +834,23 @@ class HpsGiftCardService(HpsGatewayService):
         currency = currency.lower()
         HpsInputValidation.check_amount(amount)
 
-        transaction = et.Element('GiftCardReward')
-        block1 = et.SubElement(transaction, 'Block1')
-        et.SubElement(block1, 'Amt').text = str(amount)
+        transaction = Et.Element('GiftCardReward')
+        block1 = Et.SubElement(transaction, 'Block1')
+        Et.SubElement(block1, 'Amt').text = str(amount)
         block1.append(self._hydrate_gift_card_data(gift_card))
 
         if currency == 'usd' or currency == 'points':
-            currency_element = et.SubElement(block1, 'Currency')
+            currency_element = Et.SubElement(block1, 'Currency')
             if currency == 'usd':
                 currency_element.text = 'USD'
             else:
                 currency_element.text = 'POINTS'
 
         if gratuity is not None:
-            et.SubElement(block1, 'GratuityAmtInfo').text = str(gratuity)
+            Et.SubElement(block1, 'GratuityAmtInfo').text = str(gratuity)
 
         if tax is not None:
-            et.SubElement(block1, 'TaxAmtInfo').text = str(tax)
+            Et.SubElement(block1, 'TaxAmtInfo').text = str(tax)
 
         return self._submit_transaction(transaction)
 
@@ -867,30 +858,30 @@ class HpsGiftCardService(HpsGatewayService):
         currency = currency.lower()
         HpsInputValidation.check_amount(amount)
 
-        transaction = et.Element('GiftCardSale')
-        block1 = et.SubElement(transaction, 'Block1')
-        et.SubElement(block1, 'Amt').text = str(amount)
+        transaction = Et.Element('GiftCardSale')
+        block1 = Et.SubElement(transaction, 'Block1')
+        Et.SubElement(block1, 'Amt').text = str(amount)
         block1.append(self._hydrate_gift_card_data(gift_card))
 
         if currency == 'usd' or currency == 'points':
-            currency_element = et.SubElement(block1, 'Currency')
+            currency_element = Et.SubElement(block1, 'Currency')
             if currency == 'usd':
                 currency_element.text = 'USD'
             else:
                 currency_element.text = 'POINTS'
 
         if gratuity is not None:
-            et.SubElement(block1, 'GratuityAmtInfo').text = str(gratuity)
+            Et.SubElement(block1, 'GratuityAmtInfo').text = str(gratuity)
 
         if tax is not None:
-            et.SubElement(block1, 'TaxAmtInfo').text = str(tax)
+            Et.SubElement(block1, 'TaxAmtInfo').text = str(tax)
 
         return self._submit_transaction(transaction)
 
     def void(self, transaction_id):
-        trans = et.Element('GiftCardVoid')
-        block1 = et.SubElement(trans, 'Block1')
-        et.SubElement(block1, 'GatewayTxnId').text = str(transaction_id)
+        trans = Et.Element('GiftCardVoid')
+        block1 = Et.SubElement(trans, 'Block1')
+        Et.SubElement(block1, 'GatewayTxnId').text = str(transaction_id)
 
         return self._submit_transaction(trans)
 
@@ -898,14 +889,14 @@ class HpsGiftCardService(HpsGatewayService):
         currency = currency.lower()
         HpsInputValidation.check_amount(amount)
 
-        transaction = et.Element('GiftCardReversal')
-        block1 = et.SubElement(transaction, 'Block1')
-        et.SubElement(block1, 'Amt').text = str(amount)
+        transaction = Et.Element('GiftCardReversal')
+        block1 = Et.SubElement(transaction, 'Block1')
+        Et.SubElement(block1, 'Amt').text = str(amount)
 
         if isinstance(card_data, HpsGiftCard):
             block1.append(self._hydrate_gift_card_data(card_data))
         else:
-            et.SubElement(block1, 'GatewayTxnId').text = str(card_data)
+            Et.SubElement(block1, 'GatewayTxnId').text = str(card_data)
 
         return self._submit_transaction(transaction)
 
@@ -918,6 +909,7 @@ class HpsGiftCardService(HpsGatewayService):
             rsp['Transaction'][transaction.tag]['RspCode'],
             rsp['Transaction'][transaction.tag]['RspText'])
 
+        rvalue = None
         if transaction.tag == 'GiftCardActivate':
             rvalue = HpsGiftCardActivate.from_dict(rsp)
         elif transaction.tag == 'GiftCardAddValue':
@@ -942,19 +934,19 @@ class HpsGiftCardService(HpsGatewayService):
         return rvalue
 
     def _hydrate_gift_card_data(self, gift_card, element_name='CardData'):
-        card_element = et.Element(element_name)
+        card_element = Et.Element(element_name)
         if gift_card.is_track_data is True:
-            et.SubElement(card_element, 'TrackData').text = gift_card.number
+            Et.SubElement(card_element, 'TrackData').text = gift_card.number
         else:
-            et.SubElement(card_element, 'CardNbr').text = gift_card.number
+            Et.SubElement(card_element, 'CardNbr').text = gift_card.number
 
         if gift_card.encryption_data is not None:
             data = gift_card.encryption_data
-            enc_element = et.SubElement(card_element, 'EncryptionData')
-            et.SubElement(enc_element, 'EncryptedTrackNumber').text = \
+            enc_element = Et.SubElement(card_element, 'EncryptionData')
+            Et.SubElement(enc_element, 'EncryptedTrackNumber').text = \
                 data.encrypted_track_number
-            et.SubElement(enc_element, 'KSN').text = data.ksn
-            et.SubElement(enc_element, 'KTB').text = data.ktb
-            et.SubElement(enc_element, 'Version').text = data.version
+            Et.SubElement(enc_element, 'KSN').text = data.ksn
+            Et.SubElement(enc_element, 'KTB').text = data.ktb
+            Et.SubElement(enc_element, 'Version').text = data.version
 
-        return card_element
\ No newline at end of file
+        return card_element
